"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Version_1 = require("./Version");
var Browser;
(function (Browser) {
    Browser[Browser["Other"] = 0] = "Other";
    Browser[Browser["Chrome"] = 1] = "Chrome";
    Browser[Browser["Edge"] = 2] = "Edge";
    Browser[Browser["Firefox"] = 3] = "Firefox";
    Browser[Browser["IE"] = 4] = "IE";
    Browser[Browser["Safari"] = 5] = "Safari";
})(Browser = exports.Browser || (exports.Browser = {}));
var OS;
(function (OS) {
    OS[OS["Other"] = 0] = "Other";
    OS[OS["Android"] = 1] = "Android";
    OS[OS["IOS"] = 2] = "IOS";
    OS[OS["Linux"] = 3] = "Linux";
    OS[OS["Mac"] = 4] = "Mac";
    OS[OS["Windows"] = 5] = "Windows";
    OS[OS["WindowsPhone"] = 6] = "WindowsPhone";
})(OS = exports.OS || (exports.OS = {}));
var BrowserDetection = (function () {
    function BrowserDetection() {
    }
    BrowserDetection.getBrowserInformation = function (userAgent) {
        var agent = userAgent || BrowserDetection.getUserAgent();
        return BrowserDetection.buildBrowserInformation(agent);
    };
    BrowserDetection.getUserAgent = function () {
        return (window && window.navigator && navigator.userAgent) || '';
    };
    BrowserDetection.buildBrowserInformation = function (userAgent) {
        var agent = userAgent.toLowerCase();
        var browserInfo = {
            browser: Browser.Other,
            browserVersion: undefined,
            os: OS.Other,
            osVersion: undefined,
            userAgent: userAgent
        };
        browserInfo = BrowserDetection.fillBrowser(browserInfo, agent);
        browserInfo = BrowserDetection.fillOS(browserInfo, agent);
        return browserInfo;
    };
    BrowserDetection.fillBrowser = function (browserInfo, userAgent) {
        var browser = Browser.Other;
        var browserVersion = undefined;
        var match;
        if (match = /msie (\d+)([\d.]*)/.exec(userAgent)) {
            browser = Browser.IE;
        }
        else if (match = /trident.*rv:(\d+)([\d.]*)/.exec(userAgent)) {
            browser = Browser.IE;
        }
        else if (match = /edge\/(\d+)([\d.]*)/.exec(userAgent)) {
            browser = Browser.Edge;
        }
        else if (match = /(?:firefox|fxios)\/(\d+)([\d.]*)/.exec(userAgent)) {
            browser = Browser.Firefox;
        }
        else if (match = /(?:chrome|crios)\/(\d+)([\d.]*)/.exec(userAgent)) {
            browser = Browser.Chrome;
        }
        else if (match = /safari\/(\d+)/.exec(userAgent)) {
            browser = Browser.Safari;
            match = /version\/(\d+)([\d.]*)/.exec(userAgent);
        }
        if (match) {
            var browserMajor = parseInt(match[1], 10) || 0;
            var browserMinor = '0';
            var browserMinorVersion = match[2];
            if (browserMinorVersion) {
                var minorStart = browserMinorVersion.indexOf('.');
                if (minorStart >= 0 && minorStart < browserMinorVersion.length - 1) {
                    browserMinor = browserMinorVersion.substr(minorStart + 1);
                }
            }
            browserVersion = Version_1.default.parse(browserMajor + "." + browserMinor);
        }
        browserInfo.browser = browser;
        browserInfo.browserVersion = browserVersion;
        return browserInfo;
    };
    BrowserDetection.fillOS = function (browserInfo, userAgent) {
        var os = OS.Other;
        var osVersion = undefined;
        var osVersionMatch = /[\s\(](os|os x|windows phone|windows nt|android) ([\d._]+)/.exec(userAgent);
        osVersion = osVersionMatch ? osVersionMatch[2] : undefined;
        var deviceMatch = userAgent.match(/windows phone|wpdesktop/) || userAgent.match(/ipad|iphone|ipod|android/);
        if (deviceMatch) {
            var device = deviceMatch[0];
            if (device === 'windows phone' || device === 'wpdesktop') {
                os = OS.WindowsPhone;
            }
            if (device === 'android') {
                os = OS.Android;
            }
            if (device === 'ipad' || device === 'ipod' || device === 'iphone') {
                os = OS.IOS;
            }
        }
        else {
            if (userAgent.indexOf('macintosh') !== -1) {
                os = OS.Mac;
            }
            if (userAgent.indexOf('windows nt') !== -1) {
                os = OS.Windows;
            }
            if (/(windows 8\.1|windows nt 6\.3)/.test(userAgent)) {
                os = OS.Windows;
                osVersion = '8.1';
            }
            if (userAgent.indexOf('windows nt 10') !== -1) {
                os = OS.Windows;
                osVersion = '10';
            }
            if (userAgent.indexOf('windows nt 6.1') !== -1) {
                os = OS.Windows;
                osVersion = '7';
            }
        }
        browserInfo.os = os;
        browserInfo.osVersion = osVersion;
        return browserInfo;
    };
    return BrowserDetection;
}());
exports.default = BrowserDetection;
