"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Validate_1 = require("./Validate");
var Text_1 = require("./Text");
var SPCoreLibraryStrings_resx_1 = require("./SPCoreLibraryStrings.resx");
var Guid = (function () {
    function Guid(guid) {
        this._guid = guid;
    }
    Guid.newGuid = function (randomNumberGenerator) {
        return new Guid(Guid._generateGuid(randomNumberGenerator));
    };
    Guid.parse = function (guidString) {
        var guid = Guid.tryParse(guidString);
        if (!guid) {
            throw new Error(Text_1.default.format(SPCoreLibraryStrings_resx_1.default.invalidGuidStringError, guidString));
        }
        return guid;
    };
    Guid.tryParse = function (guid) {
        if (guid) {
            guid = Guid._normalize(guid);
            if (Guid._guidRegEx.test(guid)) {
                return new Guid(guid);
            }
        }
        return undefined;
    };
    Guid.isValid = function (guid) {
        if (guid) {
            guid = Guid._normalize(guid);
            if (Guid._guidRegEx.test(guid)) {
                return true;
            }
        }
        return false;
    };
    Guid._normalize = function (guid) {
        Validate_1.default.isNonemptyString(guid, 'guid');
        var result = /^Guid\((.*)\)/i.exec(guid); 
        if (result) {
            guid = result[1];
        }
        if (guid.length === 38) {
            guid = guid.substr(1, 36);
        }
        return guid.toLowerCase();
    };
    Guid._generateGuid = function (randomNumberGenerator) {
        return 'AAAAAAAA-AAAA-4AAA-BAAA-AAAAAAAAAAAA'.replace(/[AB]/g, 
        function (character) {
            var randomNumber = randomNumberGenerator ? randomNumberGenerator.generate() : Math.random();
            var num = randomNumber * 16 | 0;
            var masked = character === 'A' ? num : (num & 0x3 | 0x8);
            return masked.toString(16);
        });
    };
    Guid.prototype.equals = function (guid) {
        Validate_1.default.isNotNullOrUndefined(guid, 'guid');
        return guid && this._guid.toString() === guid.toString();
    };
    Guid.prototype.toString = function () {
        return this._guid;
    };
    Guid.empty = new Guid('00000000-0000-0000-0000-000000000000');
    Guid._guidRegEx = /^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i;
    return Guid;
}());
exports.default = Guid;
