import { IDisposable } from '../IDisposable';
/**
 * Used with the {@link Event} system, this interface is implemented by components that
 * can subscribe to events.
 *
 * @remarks
 * IEventObserver is an abstraction of the key features that a component must have in order
 * to subscribe to a SharePoint Framework event:  It must have instanceId and componentId
 * information for diagnostics reporting, and it must have a way to notify the event system
 * when the component is disposed, so that its handlers can be automatically removed.
 * Other objects may implement this contract, as long as they meet these requirements.
 *
 * @public
 */
export interface IEventObserver extends IDisposable {
    /**
     * The instance identifier for the component.
     *
     * @remarks
     * This will be used for diagnostic reporting, e.g. if the callback function has
     * an uncaught exception
     */
    readonly instanceId: string;
    /**
     * The component identifier, from the component's manifest.
     *
     * @remarks
     * This will be used for diagnostic reporting, e.g. if the callback function has
     * an uncaught exception
     */
    readonly componentId: string;
}
