import HttpClientConfiguration, { IHttpClientConfiguration } from '../httpClient/HttpClientConfiguration';
/**
 * Flags interface for GraphHttpClientCommonConfiguration
 *
 * @deprecated The GraphHttpClient class has been superceded by the MSGraphClient class.
 * @beta
 */
export interface IGraphHttpClientConfiguration extends IHttpClientConfiguration {
}
/**
 * Configuration for {@link GraphHttpClient}.
 *
 * @remarks
 * The GraphHttpClientConfiguration object provides a set of switches for enabling/disabling
 * various features of the GraphHttpClient class.  Normally these switches are set
 * (e.g. when calling GraphHttpClient.fetch()) by providing one of the predefined defaults
 * from GraphHttpClientConfigurations, however switches can also be changed via the
 * GraphHttpClientConfiguration.overrideWith() method.
 *
 * @deprecated The GraphHttpClient class has been superceded by the MSGraphClient class.
 * @beta
 */
export default class GraphHttpClientConfiguration extends HttpClientConfiguration implements IGraphHttpClientConfiguration {
    protected flags: IGraphHttpClientConfiguration;
    /**
     * Constructs a new instance of GraphHttpClientCommonConfiguration with the specified flags.
     *
     * @remarks
     * The default values will be used for any flags that are missing or undefined.
     * If overrideFlags is specified, it takes precedence over flags.
     */
    constructor(flags: IGraphHttpClientConfiguration, overrideFlags?: IGraphHttpClientConfiguration);
}
/**
 * Standard configurations for GraphHttpClient.
 *
 * @remarks
 * This interface provides standard predefined GraphHttpClientConfiguration objects for use with
 * the GraphHttpClient class.  In general, clients should choose the latest available
 * version number, which enables all the switches that are recommended for typical
 * scenarios.  (If new switches are introduced in the future, a new version number
 * will be introduced, which ensures that existing code will continue to function the
 * way it did at the time when it was tested.)
 *
 * @deprecated The GraphHttpClient class has been superceded by the MSGraphClient class.
 * @beta
 */
export interface IGraphHttpClientConfigurations {
    /**
     * This configuration turns off every feature switch for HttpClient.  The fetch()
     * behavior will be essentially identical to the WHATWG standard API that
     * is documented here:
     * https://fetch.spec.whatwg.org/
     */
    readonly v1: GraphHttpClientConfiguration;
}
export declare const predefinedConfigurations: IGraphHttpClientConfigurations;
