import { ServiceScope, ServiceKey } from '@microsoft/sp-core-library';
/**
 * This is a ServiceScope interface that represents the basic contract of
 * the ES6 Fetch API, without any additional SharePoint logic.
 *
 * @remarks
 * See the
 * {@link https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API | Fetch API}
 * documentation for details.
 *
 * @alpha
 */
export interface IFetchProvider {
    /**
     * The parameters and semantics for this function are the same as the
     * ES6 GlobalFetch.fetch() standard.
     *
     * @remarks
     * See the
     * {@link https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API | Fetch API}
     * documentation for details.
     */
    fetch(request: Request): Promise<Response>;
}
/**
 * The default implementation of IFetchProvider, which simply calls window.fetch().
 */
export default class FetchProvider implements IFetchProvider {
    constructor(serviceScope: ServiceScope);
    fetch(request: Request): Promise<Response>;
}
/**
 * The service key for IFetchProvider.
 *
 * @alpha
 */
export declare const fetchProviderServiceKey: ServiceKey<IFetchProvider>;
