/**
 * The Response subclass returned by methods such as HttpClient.fetch().
 *
 * @remarks
 * This is a placeholder.  In the future, additional HttpClient-specific functionality
 * may be added to this class.
 *
 * @internalremarks
 * This class exposes the same members as our typings for the browser's native
 * Response and Body classes, which is why we can say that it "implements" them.
 * It cannot actually inherit from Response because that class does not have a copy
 * constructor (because it would probably be inefficient to copy the response stream).
 *
 * @public
 */
export default class HttpClientResponse implements Response, Body {
    protected nativeResponse: Response;
    /**
     * @internal
     */
    constructor(response: Response);
    /**
     * This property is marked as alpha because it is not yet implemented by the \@microsoft/sp-polyfills package.
     *
     * @alpha
     */
    readonly body: ReadableStream | null;
    /**
     * {@inheritdoc whatwg-fetch:Body.bodyUsed}
     */
    readonly bodyUsed: boolean;
    /**
     * {@inheritdoc whatwg-fetch:Body.arrayBuffer}
     */
    arrayBuffer(): Promise<ArrayBuffer>;
    /**
     * {@inheritdoc whatwg-fetch:Body.blob}
     */
    blob(): Promise<Blob>;
    /**
     * {@inheritdoc whatwg-fetch:Body.formData}
     */
    formData(): Promise<FormData>;
    /**
     * {@inheritdoc whatwg-fetch:Body.json}
     */
    json(): Promise<any>;
    /**
     * {@inheritdoc whatwg-fetch:Body.text}
     */
    text(): Promise<string>;
    /**
     * {@inheritdoc whatwg-fetch:Response.type}
     */
    readonly type: ResponseType;
    /**
     * {@inheritdoc whatwg-fetch:Response.url}
     */
    readonly url: string;
    /**
     * {@inheritdoc whatwg-fetch:Response.status}
     */
    readonly status: number;
    /**
     * {@inheritdoc whatwg-fetch:Response.ok}
     */
    readonly ok: boolean;
    /**
     * {@inheritdoc whatwg-fetch:Response.statusText}
     */
    readonly statusText: string;
    /**
     * {@inheritdoc whatwg-fetch:Response.headers}
     */
    readonly headers: Headers;
    clone(): HttpClientResponse;
}
