"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var sp_telemetry_1 = require("@ms/sp-telemetry");
var decorators_1 = require("@microsoft/decorators");
var sp_core_library_1 = require("@microsoft/sp-core-library");
var AadConstants_1 = require("./AadConstants");
var SPHttpStrings_resx_1 = require("../SPHttpStrings.resx");
var AadTokenProvider = (function () {
    function AadTokenProvider(serviceScope) {
        this._displayCallHandler = undefined;
        this._loadAndConfigureAdalJsModulePromise = undefined;
        this._loginUserPromise = undefined;
        this._tokenAcquisitionFailureEvent = new sp_core_library_1.Event(AadTokenProvider_1._tokenAcquisitionFailureEventId);
    }
    AadTokenProvider_1 = AadTokenProvider;
    AadTokenProvider.prototype._initialize = function (azureInstanceUrl, azureTenantId) {
        sp_core_library_1.Validate.isNonemptyString(azureInstanceUrl, 'azureInstanceUrl');
        sp_core_library_1.Validate.isNonemptyString(azureTenantId, 'azureTenantId');
        this._azureInstanceUrl = azureInstanceUrl;
        this._azureTenantId = azureTenantId;
        this._isInitialized = true;
        this._tokenAcquisitionFailureEvent = new sp_core_library_1.Event(AadTokenProvider_1._tokenAcquisitionFailureEventId);
    };
    AadTokenProvider.prototype.getToken = function (resourceEndpoint) {
        var _this = this;
        if (!this._isInitialized) {
            return Promise.reject(new Error('This operation cannot be performed until the AadTokenProvider is initialized.'));
        }
        if (!sp_core_library_1._SPFlight.isEnabled(375 )) {
            return Promise.reject(new Error('The requested operation is part of an experimental feature ' +
                'that is not supported in the current environment.'));
        }
        return this._loginUser().then(function () {
            return _this._acquireTokenPromise(resourceEndpoint).then(function (token) {
                return token.token;
            });
        });
    };
    Object.defineProperty(AadTokenProvider.prototype, "tokenAcquisitionFailureEvent", {
        get: function () {
            return this._tokenAcquisitionFailureEvent;
        },
        enumerable: true,
        configurable: true
    });
    AadTokenProvider.prototype._acquireTokenPromise = function (resourceEndpoint) {
        return new Promise(function (resolve, reject) {
            var acquireAccessTokenQosMonitor = new sp_telemetry_1._QosMonitor('AadTokenProvider.AcquireAccessToken');
            AadTokenProvider_1._authContext.acquireToken(resourceEndpoint, function (message, token) {
                if (!token) {
                    if (AadTokenProvider_1._authContext._getItem(AadTokenProvider_1._authContext.CONSTANTS.STORAGE.ERROR) === 'interaction_required') {
                        var loginRedirectUri = AadTokenProvider_1._authContext.config.redirectUri;
                        var acquireRedirectUri = loginRedirectUri + '?' + AadConstants_1.default.REDIRECT_QUERY_PARAM;
                        AadTokenProvider_1._authContext.config.redirectUri = acquireRedirectUri;
                        var urlNavigate = AadTokenProvider_1._authContext
                            ._getNavigateUrl('token', resourceEndpoint) + '&prompt=select_account';
                        AadTokenProvider_1._authContext.config.redirectUri = loginRedirectUri;
                        sp_core_library_1._EventManager.instance.raiseEvent(AadTokenProvider_1._tokenAcquisitionFailureEventId, { errorMessage: SPHttpStrings_resx_1.default.multiFactorAuthenticationWarning, redirectUrl: urlNavigate });
                    }
                    reject(new Error(message));
                }
                else {
                    if (message) {
                        acquireAccessTokenQosMonitor.writeSuccess({ 'Message': message });
                    }
                    else {
                        acquireAccessTokenQosMonitor.writeSuccess();
                    }
                    alert(token);
                    resolve({
                        message: message,
                        token: token
                    });
                }
            });
        });
    };
    AadTokenProvider.prototype._loadAndConfigureAdalJsModule = function () {
        var _this = this;
        if (!this._loadAndConfigureAdalJsModulePromise) {
            this._loadAndConfigureAdalJsModulePromise = new Promise(function (resolve, reject) {
                try {
                    require.ensure(['adal-angular'], function (require) {
                        resolve(require('adal-angular'));
                    }, 'sp-http-adal');
                }
                catch (e) {
                    reject(e);
                }
            }).then(function (adalJsModule) {
                _this._configureAdalJs(adalJsModule);
                return adalJsModule;
            });
        }
        return this._loadAndConfigureAdalJsModulePromise;
    };
    AadTokenProvider.prototype._configureAdalJs = function (adalJsModule) {
        var _this = this;
        var loginPartialUri = window.location.origin + '/_forms/';
        var loginRedirectUri = sp_core_library_1._SPFlight.isEnabled(AadTokenProvider_1._sppplatWebApiPermissionRequestsClientId) ?
            loginPartialUri + AadConstants_1.default.SPFX_SINGLE_SIGN_ON_REPLY_URL :
            loginPartialUri + AadConstants_1.default.SINGLE_SIGN_ON_REPLY_URL;
        AadTokenProvider_1._authContext = adalJsModule.inject({
            clientId: sp_core_library_1._SPFlight.isEnabled(AadTokenProvider_1._sppplatWebApiPermissionRequestsClientId) ?
                AadConstants_1.default.SPO_CE_WEB_APP_PRINCIPAL_ID :
                AadConstants_1.default.SPO_WEB_APP_PRINCIPAL_ID,
            redirectUri: loginRedirectUri,
            instance: this._azureInstanceUrl + '/',
            tenant: this._azureTenantId,
            navigateToLoginRequestUrl: false,
            displayCall: function (urlNavigate) {
                if (_this._displayCallHandler) {
                    _this._displayCallHandler({
                        urlNavigate: urlNavigate,
                        redirectUri: loginRedirectUri
                    });
                }
            }
        });
    };
    AadTokenProvider.prototype._startLogin = function (showWindowCallback) {
        if (this._displayCallHandler) {
            return; 
        }
        this._displayCallHandler = function (args) {
            showWindowCallback(args);
        };
        AadTokenProvider_1._authContext._loginInProgress = false;
        AadTokenProvider_1._authContext.login();
        this._displayCallHandler = undefined;
        return;
    };
    AadTokenProvider.prototype._loginUser = function () {
        var _this = this;
        if (this._loginUserPromise) {
            return this._loginUserPromise;
        }
        return this._loadAndConfigureAdalJsModule()
            .then(function (adalJsModule) {
            sp_core_library_1.Validate.isNotNullOrUndefined(AadTokenProvider_1._authContext, 'AuthenticationContext');
            if (AadTokenProvider_1._authContext.getCachedUser()) {
                return; 
            }
            else {
                var acquireIdTokenMonitor_1 = new sp_telemetry_1._QosMonitor('AadTokenProvider.AcquireIdToken');
                var acquireIdTokenTagNameSuffix_1 = 'AcquireIdToken';
                _this._startLogin(function (args) {
                    var popupWindow = window.open(args.urlNavigate, 'login', 'width=483, height=600');
                    if (!popupWindow) {
                        var popUpDidNotOpenError = new Error('Failed to open pop-up window');
                        acquireIdTokenMonitor_1.writeExpectedFailure(acquireIdTokenTagNameSuffix_1, popUpDidNotOpenError);
                        sp_core_library_1._EventManager.instance.raiseEvent(AadTokenProvider_1._tokenAcquisitionFailureEventId, { errorMessage: SPHttpStrings_resx_1.default.disablePopUpBlockerWarning });
                        throw popUpDidNotOpenError;
                    }
                    if (popupWindow.closed === undefined) {
                        var popUpClosedPropertyMissingError = new Error('This operation requires the popupWindow.closed property, which is not supported in this browser');
                        acquireIdTokenMonitor_1.writeExpectedFailure(acquireIdTokenTagNameSuffix_1, popUpClosedPropertyMissingError);
                        throw popUpClosedPropertyMissingError;
                    }
                    if (popupWindow.focus) {
                        popupWindow.focus();
                    }
                    _this._loginUserPromise = _this._waitForWindowToClose(popupWindow, args)
                        .then(function () {
                        acquireIdTokenMonitor_1.writeSuccess();
                        _this._loginUserPromise = undefined;
                    }).catch(function (e) {
                        acquireIdTokenMonitor_1.writeExpectedFailure(acquireIdTokenTagNameSuffix_1, e);
                        _this._loginUserPromise = undefined;
                        throw e;
                    });
                });
                if (!_this._loginUserPromise) {
                    var unreachableError = new Error('Should be impossible.');
                    acquireIdTokenMonitor_1.writeUnexpectedFailure(acquireIdTokenTagNameSuffix_1, unreachableError);
                    throw unreachableError;
                }
                return _this._loginUserPromise;
            }
        });
    };
    AadTokenProvider.prototype._waitForWindowToClose = function (popupWindow, args) {
        return new Promise(function (resolve, reject) {
            var WINDOW_POLL_MS = 10;
            var ATTEMPTS_TO_POLL_WINDOW = !DEPRECATED_UNIT_TEST ? 500 : 1;
            try {
                var currentNumberOfPollAttempts_1 = 0;
                var pollTimer_1 = window.setInterval(function () {
                    if (currentNumberOfPollAttempts_1 === ATTEMPTS_TO_POLL_WINDOW) {
                        window.clearInterval(pollTimer_1);
                        popupWindow.close();
                        reject(new Error('Login popup failed to redirect to the designated redirect uri.'));
                        return;
                    }
                    if (popupWindow.closed) {
                        window.clearInterval(pollTimer_1);
                        reject(new Error('Window closed without authenticating'));
                        return;
                    }
                    if (popupWindow.document.URL.indexOf(args.redirectUri) !== -1) {
                        window.clearInterval(pollTimer_1);
                        if (!popupWindow.location.hash) {
                            popupWindow.close();
                            reject(new Error('Login popup redirected to the redirect uri but no id token was found.'));
                            return;
                        }
                        AadTokenProvider_1._authContext.handleWindowCallback(popupWindow.location.hash);
                        popupWindow.close();
                        resolve();
                        return;
                    }
                    currentNumberOfPollAttempts_1++;
                }, WINDOW_POLL_MS);
            }
            catch (e) {
                reject(e);
            }
        });
    };
    AadTokenProvider.serviceKey = sp_core_library_1.ServiceKey.create('sp-http:AadTokenProvider', AadTokenProvider_1);
    AadTokenProvider._tokenAcquisitionFailureEventId = 'Token Acquistion Failure';
    AadTokenProvider._sppplatWebApiPermissionRequestsClientId = 568;
    AadTokenProvider = AadTokenProvider_1 = tslib_1.__decorate([
        decorators_1.sealed
    ], AadTokenProvider);
    return AadTokenProvider;
    var AadTokenProvider_1;
}());
exports.default = AadTokenProvider;
