import SPHttpClientCommonConfiguration, { ISPHttpClientCommonConfiguration } from './SPHttpClientCommonConfiguration';
/**
 * Flags interface for SPHttpClientBatchConfiguration.
 *
 * @beta
 */
export interface ISPHttpClientBatchConfiguration extends ISPHttpClientCommonConfiguration {
}
/**
 * Configuration for SPHttpClientBatch.
 *
 * @remarks
 * The SPHttpClientBatchConfiguration object provides a set of switches for enabling/disabling
 * various features of the SPHttpClientBatch class.  Normally these switches are set
 * (e.g. when calling SPHttpClientBatch.fetch()) by providing one of the predefined defaults
 * from SPHttpClientBatchConfigurations, however switches can also be changed via the
 * SPHttpClientBatchConfiguration.overrideWith() method.
 *
 * @beta
 */
export default class SPHttpClientBatchConfiguration extends SPHttpClientCommonConfiguration implements ISPHttpClientBatchConfiguration {
    protected flags: ISPHttpClientBatchConfiguration;
    /**
     * Constructs a new instance of SPHttpClientBatchConfiguration with the specified flags.
     * The default values will be used for any flags that are missing or undefined.
     * If overrideFlags is specified, it takes precedence over flags.
     */
    constructor(flags: ISPHttpClientBatchConfiguration, overrideFlags?: ISPHttpClientBatchConfiguration);
    overrideWith(sourceFlags: ISPHttpClientBatchConfiguration): SPHttpClientBatchConfiguration;
    protected initializeFlags(): void;
}
/**
 * Standard configurations for SPHttpClient.
 *
 * @remarks
 * This interface provides standard predefined SPHttpClientBatchConfiguration objects for use with
 * the SPHttpClientBatch class.  In general, clients should choose the latest available
 * version number, which enables all the switches that are recommended for typical
 * scenarios.  (If new switches are introduced in the future, a new version number
 * will be introduced, which ensures that existing code will continue to function the
 * way it did at the time when it was tested.)
 *
 * @beta
 */
export interface ISPHttpClientBatchConfigurations {
    /**
     * Version 1 enables these switches:
     * consoleLogging = true;
     * jsonRequest = true;
     * jsonResponse = true
     */
    readonly v1: SPHttpClientBatchConfiguration;
}
export declare const predefinedConfigurations: ISPHttpClientBatchConfigurations;
