"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ComponentStore_1 = require("./../stores/ComponentStore");
var SPComponentLoaderProxy_1 = require("./../SPComponentLoaderProxy");
var componentConstants = require("./../utilities/componentConstants");
var DeveloperToolsLoader_resx_1 = require("./DeveloperToolsLoader.resx");
var BACKTICK_KEYCODE = 192;
var F12_KEYCODE = 123;
var MAC_PLATFORM_IDENTIFIER = 'MacIntel';
require.include('@microsoft/load-themed-styles');
var _listenerHasBeenRegistered = false;
var _developerTools;
var _developerToolsTabsBacklog = [];
function initialize() {
    if (!_listenerHasBeenRegistered) {
        document.documentElement.addEventListener('keydown', function (event) {
            var isMac = navigator.platform === MAC_PLATFORM_IDENTIFIER;
            if (((event.ctrlKey && !event.metaKey) || (isMac && event.metaKey && !event.ctrlKey)) && !event.altKey) {
                if (event.shiftKey) {
                    if (event.keyCode === BACKTICK_KEYCODE) {
                        alert(DeveloperToolsLoader_resx_1.default.developerToolsKeyComboDeprecationMessage);
                        event.preventDefault();
                    }
                }
                else {
                    if (event.keyCode === F12_KEYCODE) {
                        toggleDeveloperTools();
                        event.preventDefault();
                    }
                }
            }
        });
        _listenerHasBeenRegistered = true;
    }
}
exports.initialize = initialize;
function registerDeveloperToolsTab(developerToolsTab) {
    if (_developerTools) {
        _developerTools.registerDeveloperToolsTab(developerToolsTab);
    }
    else {
        _developerToolsTabsBacklog.push(developerToolsTab);
    }
}
exports.registerDeveloperToolsTab = registerDeveloperToolsTab;
function toggleDeveloperTools() {
    if (_developerTools) {
        _developerTools.toggleDeveloperTools();
    }
    else {
        if (NPM_BUILD) {
            require.include('react');
            require.include('react-dom');
            var reactPromise = SPComponentLoaderProxy_1.default.loadComponentById(componentConstants.reactComponentId);
            var reactDomPromise = SPComponentLoaderProxy_1.default.loadComponentById(componentConstants.reactDomComponentId);
            Promise.all([reactPromise, reactDomPromise])
                .then(function (results) {
                var react = results[0];
                var reactDom = results[1];
                _injectReactIntoCache(react, reactDom);
                require.ensure(['./DeveloperTools'], function (require) {
                    _initializeDeveloperTools(require('./DeveloperTools').default);
                }, 'developer-tools');
            });
        }
        else if (_hasReact()) {
            var reactPromise = ComponentStore_1.default.instance.getComponentById(componentConstants.reactComponentId);
            var reactDomPromise = ComponentStore_1.default.instance.getComponentById(componentConstants.reactDomComponentId);
            Promise.all([reactPromise, reactDomPromise])
                .then(function (results) {
                var react = results[0];
                var reactDom = results[1];
                _injectReactIntoCache(react, reactDom);
                _loadDeveloperTools(_tryFillDevToolsFabric());
            });
        }
        else {
            require.ensure(['react', 'react-dom'], function () {
                require.ensure(['./DeveloperToolsFabric'], function () {
                    require.ensure(['./DeveloperTools'], function (require) {
                        _initializeDeveloperTools(require('./DeveloperTools').default);
                    }, 'developer-tools');
                }, 'developer-tools-fabric');
            }, 'sp-loader-react');
        }
    }
}
exports.toggleDeveloperTools = toggleDeveloperTools;
function _hasReact() {
    var react = ComponentStore_1.default.instance.tryGetComponentById(componentConstants.reactComponentId, false);
    var reactDom = ComponentStore_1.default.instance.tryGetComponentById(componentConstants.reactDomComponentId, false);
    return !!(react && reactDom);
}
function _tryFillDevToolsFabric() {
    var fabricPromise = ComponentStore_1.default.instance.tryGetComponentById(componentConstants.officeUiFabricReactComponentId, false);
    if (fabricPromise) {
        var fabricId_1 = require.resolveWeak('./DeveloperToolsFabric');
        return fabricPromise.then(function (fabric) {
            if (!require.cache[fabricId_1]) {
                require.cache[fabricId_1] = {
                    exports: fabric
                };
            }
            else {
                require.cache[fabricId_1].exports = fabric;
            }
            return true;
        }, function (error) {
            return false;
        });
    }
    else {
        return Promise.resolve(false);
    }
}
function _injectReactIntoCache(react, reactDom) {
    var reactId = require.resolveWeak('react');
    var reactLibId = require.resolveWeak('react/lib/React');
    var reactDomId = require.resolveWeak('react-dom');
    if (!require.cache[reactId]) {
        require.cache[reactId] = {
            exports: react
        };
    }
    else {
        require.cache[reactId].exports = react;
    }
    if (!require.cache[reactLibId]) {
        require.cache[reactLibId] = {
            exports: react
        };
    }
    else {
        require.cache[reactLibId].exports = react;
    }
    if (!require.cache[reactDomId]) {
        require.cache[reactDomId] = {
            exports: reactDom
        };
    }
    else {
        require.cache[reactDomId].exports = reactDom;
    }
}
function _loadDeveloperTools(fabricLoadedPromise) {
    var loadDeveloperTools = function () {
        __webpack_chunk_load__(resolveChunk('developer-tools'))
            .then(function () {
            _initializeDeveloperTools(__webpack_require__(require.resolveWeak('./DeveloperTools')).default);
        });
    };
    fabricLoadedPromise.then(function (fabricLoaded) {
        if (!fabricLoaded) {
            __webpack_chunk_load__(resolveChunk('developer-tools-fabric')).then(loadDeveloperTools);
        }
        else {
            loadDeveloperTools();
        }
    });
}
function _initializeDeveloperTools(developerToolsClass) {
    _developerTools = developerToolsClass.instance;
    _developerTools.initialize();
    _developerToolsTabsBacklog.forEach(function (developerToolsTab) {
        _developerTools.registerDeveloperToolsTab(developerToolsTab);
    });
    _developerTools.showHideDeveloperTools(true);
}
