"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var sp_telemetry_1 = require("@ms/sp-telemetry");
var SPLoaderError_1 = require("./SPLoaderError");
var telemetryConstants = require("../utilities/telemetryConstants");
var loadComponentImplEventName = 'loadComponentImpl';
var ErrorBuilder = (function () {
    function ErrorBuilder() {
    }
    ErrorBuilder.buildLoadComponentError = function (manifest, error) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadComponentError, error, false, telemetryConstants.loadComponentLogSource, loadComponentImplEventName, manifest.id, manifest.alias, error.message);
    };
    ErrorBuilder.buildLoadComponentReturnsEmptyError = function (manifest) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadComponentReturnsEmptyError, undefined, false, telemetryConstants.loadComponentLogSource, loadComponentImplEventName, manifest.id, manifest.alias);
    };
    ErrorBuilder.buildLoadComponentReturnsDefaultEmptyError = function (manifest) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadComponentReturnsDefaultEmptyError, undefined, false, telemetryConstants.loadComponentLogSource, loadComponentImplEventName, manifest.id, manifest.alias);
    };
    ErrorBuilder.buildLoadComponentDependencyError = function (manifest, error) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadComponentDependencyError, error, false, telemetryConstants.loadComponentLogSource, loadComponentImplEventName, manifest.id, manifest.alias, error.message);
    };
    ErrorBuilder.buildManifestNotFoundError = function (moduleConfiguration) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.manifestNotFoundError, undefined, false, telemetryConstants.loadComponentLogSource, undefined, moduleConfiguration.id, moduleConfiguration.version);
    };
    ErrorBuilder.buildLoadPathDependencyBlockedError = function (manifest, name) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadPathDependencyBlockedByAnotherDependencyError, undefined, false, telemetryConstants.loadComponentLogSource, undefined, name, manifest.id, manifest.alias);
    };
    ErrorBuilder.buildModuleHasUndeclaredDependencyError = function (manifest, dependencyName) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.moduleHasUndeclaredDependencyError, undefined, true, 
        telemetryConstants.loadComponentLogSource, undefined, manifest.id, manifest.alias, dependencyName);
    };
    ErrorBuilder.buildLoadEntryPointError = function (manifest, error) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadEntryPointError, error, false, telemetryConstants.loadComponentLogSource, undefined, manifest.id, manifest.alias, error.message);
    };
    ErrorBuilder.buildLoadPathDependencyError = function (manifest, dependencyName, error) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadPathDependencyError, error, false, telemetryConstants.loadComponentLogSource, undefined, dependencyName, manifest.id, manifest.alias, error.message);
    };
    ErrorBuilder.buildLoadComponentDependencyFailoverPathError = function (manifest, dependencyName, failoverPath, error) {
        return this.buildErrorWithVerboseLog(SPLoaderError_1.SPLoaderErrorCode.loadComponentDependencyFailoverPathError, error, false, telemetryConstants.loadComponentLogSource, undefined, dependencyName, failoverPath, manifest.id, manifest.alias, error.message);
    };
    ErrorBuilder.buildLoadScriptWithStringError = function () {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.loadScriptWithStringError, undefined, true, 
        telemetryConstants.loadScriptLogSource, undefined);
    };
    ErrorBuilder.buildUrlStatusLocalhostFileNotFoundError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusLocalhostFileNotFoundError, undefined, true, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusFileNotFoundError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusFileNotFoundError, undefined, true, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusForbiddenError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusForbiddenError, undefined, true, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusClientErrorError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusClientErrorError, undefined, false, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusServerErrorError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusServerErrorError, undefined, false, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusLocalhostNetworkErrorError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusLocalhostNetworkErrorError, undefined, true, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusHttpsNetworkErrorError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusHttpsNetworkErrorError, undefined, false, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusNetworkErrorError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusNetworkErrorError, undefined, false, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildUrlStatusUndefinedError = function (manifest, resourceName, url) {
        return this.buildErrorWithErrorLog(SPLoaderError_1.SPLoaderErrorCode.urlStatusUndefinedError, undefined, false, 
        telemetryConstants.loadScriptLogSource, undefined, manifest.id, manifest.alias, resourceName, url);
    };
    ErrorBuilder.buildErrorWithVerboseLog = function (errorCode, innerError, isExpected, source, eventName) {
        var params = []; 
        for (var _i = 5 
        ; _i < arguments.length 
        ; _i++ 
        ) {
            params[_i - 5] = arguments[_i]; 
        }
        var error = new (SPLoaderError_1.default.bind.apply(SPLoaderError_1.default, [void 0, errorCode, innerError, isExpected].concat(params)))();
        sp_telemetry_1._TraceLogger.logVerbose(source, error.message, eventName);
        return error;
    };
    ErrorBuilder.buildErrorWithErrorLog = function (errorCode, innerError, isExpected, source, eventName) {
        var params = []; 
        for (var _i = 5 
        ; _i < arguments.length 
        ; _i++ 
        ) {
            params[_i - 5] = arguments[_i]; 
        }
        var error = new (SPLoaderError_1.default.bind.apply(SPLoaderError_1.default, [void 0, errorCode, innerError, isExpected].concat(params)))();
        sp_telemetry_1._TraceLogger.logError(source, error, eventName);
        return error;
    };
    return ErrorBuilder;
}());
exports.default = ErrorBuilder;
