import { IODataChangeToken } from './SmallTypes';
/**
 * Represents an OData SP.List object.  For more information about this object
 * see the MSDN documentation here:
 * https://msdn.microsoft.com/en-us/library/office/jj860569.aspx
 *
 * @public
 */
export interface IODataList {
    /**
     * The list definition type on which the list is based.
     */
    BaseTemplate: number;
    /**
     * Example: "/Date(1453294804000)/"
     */
    Created: string;
    /**
     * The change token that will be used in logging the next change to the list.
     */
    CurrentChangeToken: IODataChangeToken;
    /**
     * A description of the List.
     */
    Description: string;
    /**
     * A hidden list does not appear on the Documents and Lists page, Quick Launch bar,
     * the Modify Site Content page, or the Add Column page as an option for lookup fields.
     */
    Hidden: boolean;
    /**
     * Example: "/Guid(9fb9199b-65f2-4a4a-b597-11d1a44422c1)/"
     */
    Id: string;
    /**
     * Example: "/Date(1453294809000)/"
     */
    LastItemDeletedDate: string;
    /**
     * Example: "/Date(1453294809000)/"
     */
    LastItemModifiedDate: string;
    /**
     * Example: "/sites/PubSite"
     */
    ParentWebUrl: string;
    /**
     * Example: "/Guid(22a9ef51-737b-4ff2-9346-694633fe4416)/"
     */
    TemplateFeatureId: string;
    /**
     * Example: "Pages"
     */
    Title: string;
    /**
     * Example: "MyListTitleList"
     */
    EntityTypeName: string;
    /**
     * Example: "SP.Data.MyListTitleListItem"
     */
    ListItemEntityTypeFullName: string;
}
export default IODataList;
