/**
 * Represents an OData SP.NavigationNode object.
 * https://msdn.microsoft.com/en-us/library/office/jj246311.aspx
 *
 * @public
 */
export interface IODataNavigationNode {
    /**
     * Gets a value that specifies the identifier for the navigation node.
     */
    Id?: number;
    IsDocLib?: boolean;
    /**
     * Gets or sets a value that specifies whether the navigation node URL potentially
     * corresponds to pages outside of the site collection.
     */
    IsExternal?: boolean;
    /**
     * Gets or sets a value that specifies if the node navigation link should be visible.
     */
    IsVisible?: boolean;
    /**
     * Gets or sets a value that specifies the anchor text for the node navigation link.
     */
    Title?: string;
    /**
     * Gets or sets a value that specifies the URL to be stored with the navigation node.
     * It must be a URL of relative form if IsExternal is false. It must be a URL of
     * relative or absolute form.
     */
    Url?: string;
    /**
     * Gets or sets an array of Navigation Nodes that are children to the current node.
     */
    Children?: IODataNavigationNode[];
}
/**
 * Represents an OData Microsoft.SharePoint.Navigation.SPNavigation object.
 * https://msdn.microsoft.com/en-us/library/office/ee557907.aspx
 *
 * @public
 */
export interface IODataNavigationNodeCollection {
    /**
     * Gets an SPNavigationNode object that contains
     * the nodes in the Quick Launch area of the site.
     */
    quickLaunch: IODataNavigationNode[];
    /**
     * Gets an SPNavigationNode object that contains the nodes in the top link bar
     * for the website.
     */
    topNav: IODataNavigationNode[];
}
export default IODataNavigationNodeCollection;
