/**
 * Represents an OData SP.UserId object.  For more information about this object
 * see the MSDN documentation here:
 * https://msdn.microsoft.com/en-us/library/office/jj860569.aspx
 *
 * @public
 */
export interface IODataUserId {
    /**
     * Example: "s-1-5-21-2127521184-1604012920-1887927527-2632426"
     */
    NameId: string;
    /**
     * Example: "urn:office:idp:activedirectory"
     */
    NameIdIssuer: string;
}
/**
 * Represents an OData SP.User object.  For more information about this object
 * see the MSDN documentation here:
 * https://msdn.microsoft.com/en-us/library/office/jj860569.aspx
 *
 * @public
 */
export interface IODataUser {
    Id: number;
    /**
     * Example: "someone@example.com"
     */
    Email: string;
    /**
     * Boolean value that specifies whether the user is a site collection administrator.
     */
    IsSiteAdmin: boolean;
    /**
     * Example: "i:0#.w|domain\user"
     */
    LoginName: string;
    /**
     * This enumeration has a FlagsAttribute attribute that allows a bitwise combination of
     * its member values.
     * @remarks
     *
     * Values:
     *
     * None: 0
     *
     * User: 1
     *
     * DistributionList: 2
     *
     * SecurityGroup: 4
     *
     * SharePointGroup: 8
     *
     * All: 15
     */
    PrincipalType: number;
    /**
     * Example: "DOMAIN\user"
     */
    Title: string;
    /**
     * Gets the information of the user that contains the user's name identifier and the
     * issuer of the user's name identifier.
     */
    UserId: IODataUserId;
}
export default IODataUser;
