import IODataBasePermission from './IODataBasePermission';
/**
 * Represents an OData SP.UserCustomAction object.  For more information about this object
 * see the MSDN documentation here:
 * https://msdn.microsoft.com/en-us/library/office/dn531432.aspx#bk_UserCustomAction
 *
 * @public
 */
export interface IODataUserCustomAction {
    /**
     * The unique identifier of the client-side component defined with SharePoint Framework
     *
     * @remarks
     * Example: "359af2a7-b73c-4aac-874c-60a865da0be7"
     */
    ClientSideComponentId: string;
    /**
     * Custom initialization properties for the client-side component.
     *
     * @remarks
     * This property is only used when a ClientSideComponentId is specified. It is optional.
     * If non-empty, the string must contain a JSON object with custom initialization properties
     * whose format and meaning are defined by the client-side component.
     *
     * Example: "{ \"maxItemsToShow\": 123 }"
     */
    ClientSideComponentProperties: string;
    /**
     * Gets or sets a value that specifies an implementation specific XML fragment that
     * determines user interface properties of the custom action.
     */
    CommandUIExtension: string;
    /**
     * Gets or sets the description of the custom action.
     */
    Description: string;
    /**
     * Gets or sets a value that specifies an implementation-specific value that determines
     * the position of the custom action in the page.
     */
    Group: string;
    /**
     * Gets a value that specifies the identifier (GUID) of the custom action.
     * Example: "48309f28-53aa-43ed-b113-625120e5af6f"
     */
    Id: string;
    /**
     * Gets or sets the URL of the image associated with the custom action.
     */
    ImageUrl: string;
    /**
     * Gets or sets the location of the custom action.
     * @remarks
     * Example: "ClientSide.Application"
     */
    Location: string;
    /**
     * Gets or sets the value that specifies the identifier of the object associated with
     * the custom action.
     */
    RegistrationId: string;
    /**
     * Gets or sets the value that specifies the type of object associated with the custom action.
     * @remarks
     * Represents an SP.UserCustomActionRegistrationType value:
     * None = 0; List = 1; ContentType = 2; ProgId = 3; FileType = 4.
     */
    RegistrationType: number;
    /**
     * Gets or sets the value that specifies the permissions needed for the custom action.
     */
    Rights: IODataBasePermission;
    /**
     * Gets a value that specifies the scope of the custom action.
     */
    Scope: number;
    /**
     * Gets or sets the value that specifies the ECMAScript to be executed when the custom action is performed.
     */
    ScriptBlock: string;
    /**
     * Gets or sets a value that specifies the URI of a file which contains the ECMAScript to execute
     * on the page.
     */
    ScriptSrc: string;
    /**
     * Gets or sets the value that specifies an implementation-specific value that determines the
     * order of the custom action that appears on the page.
     */
    Sequence: number;
    /**
     * Gets or sets the display title of the custom action.
     */
    Title: string;
    /**
     * Gets or sets the URL, URI, or ECMAScript (JScript, JavaScript) function associated with the action.
     */
    Url: string;
    /**
     * Gets a value that specifies an implementation specific version identifier.
     * @remarks
     * Example: "16.0.1.0"
     */
    VersionOfUserCustomAction: string;
}
export default IODataUserCustomAction;
