import { IODataChangeToken } from './SmallTypes';
/**
 * Represents an OData SP.Web object.  For more information about this object
 * see the MSDN documentation here:
 * https://msdn.microsoft.com/en-us/library/office/jj860569.aspx
 *
 * @public
 */
export interface IODataWeb {
    /**
     * Gets a value that specifies when the site was created.
     * Example: "/Date(2016,0,20,12,58,7,0)/"
     */
    Created?: string;
    /**
     * Represents the unique sequential location of a change within the change log.
     */
    CurrentChangeToken?: IODataChangeToken;
    /**
     * Gets or sets the URL for a custom master page file to apply to the website.
     * Example: "/sites/PubSite/_catalogs/masterpage/seattle.master"
     */
    CustomMasterUrl?: string;
    /**
     * Gets or sets the description for the site.
     */
    Description?: string;
    /**
     * Gets a value that specifies the site identifier for the site.
     * Example: "/Guid(92ea328e-9f50-49a6-9da5-2f2dd5577041)/"
     */
    Id?: string;
    /**
     * Value that represents if the web was
     */
    IsMultilingual?: boolean;
    /**
     * Gets a value that specifies the LCID for the language that is used on the site.
     * Example: 1033
     */
    Language?: number;
    /**
     * Gets a value that specifies when an item was last modified in the site.
     * Example: "/Date(1453618828000)/"
     */
    LastItemModifiedDate?: string;
    /**
     * Gets or sets the URL of the master page that is used for the website.
     * Example: "/sites/PubSite/_catalogs/masterpage/seattle.master"
     */
    MasterUrl?: string;
    /**
     * Determines if a particular web will be crawled by search or not.
     */
    NoCrawl?: boolean;
    /** Gets or sets a value that specifies whether the Quick Launch area is enabled on the site.
     */
    QuickLaunchEnabled?: boolean;
    /** Gets or sets a value that determines whether the recycle bin is enabled for the website.
     */
    RecycleBinEnabled?: boolean;
    /**
     * Gets or sets the server-relative URL for the Web site.
     * Example: "/sites/PubSite"
     */
    ServerRelativeUrl?: string;
    /**
     * Gets the url for the logo of this particular site.
     */
    SiteLogoUrl?: string;
    /**
     * The title of the web.
     */
    Title?: string;
    /**
     * Gets or sets the user interface (UI) version of the Web site.
     * Example: 15
     */
    UIVersion?: number;
    /**
     * Gets the absolute URL for the website.
     * Example: "http://example.com/sites/PubSite"
     */
    Url?: string;
    /**
     * Gets the name of the site definition or site template that was used to create the site.
     * Example: "BLANKINTERNET"
     */
    WebTemplate?: string;
}
export default IODataWeb;
