import { Guid } from '@microsoft/sp-core-library';
/**
 * Object that represents the data neccesary to build an O365Group object.
 *
 * @internal
 */
export interface IO365GroupAssociationData {
    /**
     * {@inheritdoc  O365GroupAssociation.id}
     */
    id: string;
    /**
     * {@inheritdoc  O365GroupAssociation.type}
     */
    type: string;
}
/**
 * {@inheritdoc  O365GroupAssociation.type}
 * @alpha
 */
export declare enum O365GroupAssociationType {
    Unknown = 0,
    Private = 1,
    Public = 2,
}
/**
  * This class is primarily used with the PageContext class. If the site is associated with an O365
  * group, this object provides contextual information about the group.
  *
  * @alpha
  */
export default class O365GroupAssociation {
    private _id;
    private _type;
    /**
     * @internal
     */
    constructor(data: IO365GroupAssociationData);
    /**
     * The guid associated with the site's O365 Group.
     */
    readonly id: Guid;
    /**
     * This enum identifies if the associated O365 Group private or public or unknown.
     */
    readonly type: O365GroupAssociationType;
    /**
     * Function that throws an exception if an IO365GroupAssociationData object or its parameters are
     * null or undefined.
     *
     * @param data - Data used to construct an IO365GroupAssociationData object
     */
    private _validate(data);
}
