import { Guid } from '@microsoft/sp-core-library';
/**
 * @internal
 */
export interface ISPFieldData {
    id: string;
    internalName: string;
    fieldType: string;
    isRequired: boolean;
    displayName: string;
    clientSideComponentId: string;
    clientSideComponentProperties: string;
}
/**
 * The client-side equivalent for SharePoint SPField class. Used in Fields property of SPList and SPListItem classes.
 * A field represents the data model for a column in SharePoint list view.
 *
 * @public
 */
export default class SPField {
    private _id;
    private _internalName;
    private _fieldType;
    private _required;
    private _displayName;
    private _clientSideComponentId;
    private _clientSideComponentProperties;
    /**
     * @internal
     */
    constructor(data: ISPFieldData);
    /**
     * The GUID identifier for this field.
     */
    readonly id: Guid;
    /**
     * The internal name of the field. This name is usually used to find the field.
     */
    readonly internalName: string;
    /**
     * The type of the field represented as a string
     */
    readonly fieldType: string;
    /**
     * Whether the field is required for each list item in the list
     */
    readonly isRequired: boolean;
    /**
     * The display name of the field. This name is shown as column name in UI.
     */
    readonly displayName: string;
    /**
     * The unique identifier of the client-side component associated with the field.
     */
    readonly clientSideComponentId: Guid | undefined;
    /**
     * This property is only used when a ClientSideComponentId is specified.  It is optional.
     * If non-empty, the string must contain a JSON object with custom initialization properties
     * whose format and meaning are defined by the client-side component.
     */
    readonly clientSideComponentProperties: string;
    private _validate(data);
}
