"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var SPPermission = (function () {
    function SPPermission(value) {
        if (!value || value.High === undefined || value.Low === undefined) {
            throw new Error('Must use an object with a Low and High number value');
        }
        this._value = value;
    }
    Object.defineProperty(SPPermission.prototype, "value", {
        get: function () {
            return this._value;
        },
        enumerable: true,
        configurable: true
    });
    SPPermission.prototype.hasAnyPermissions = function () {
        var _this = this;
        var requestedPerms = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            requestedPerms[_i] = arguments[_i];
        }
        return (requestedPerms || []).some(function (permission) {
            return _this.hasPermission(permission);
        });
    };
    SPPermission.prototype.hasAllPermissions = function () {
        var _this = this;
        var requestedPerms = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            requestedPerms[_i] = arguments[_i];
        }
        return (requestedPerms || []).every(function (permission) {
            return _this.hasPermission(permission);
        });
    };
    SPPermission.prototype.hasPermission = function (requestedPerm) {
        return requestedPerm &&
            ((requestedPerm.value.Low & this.value.Low) === requestedPerm.value.Low) &&
            ((requestedPerm.value.High & this.value.High) === requestedPerm.value.High);
    };
    SPPermission.emptyMask = new SPPermission({ High: 0x0, Low: 0x0 });
    SPPermission.viewListItems = new SPPermission({ High: 0x0, Low: 0x1 });
    SPPermission.addListItems = new SPPermission({ High: 0x0, Low: 0x2 });
    SPPermission.editListItems = new SPPermission({ High: 0x0, Low: 0x4 });
    SPPermission.deleteListItems = new SPPermission({ High: 0x0, Low: 0x8 });
    SPPermission.approveItems = new SPPermission({ High: 0x0, Low: 0x10 });
    SPPermission.openItems = new SPPermission({ High: 0x0, Low: 0x20 });
    SPPermission.viewVersions = new SPPermission({ High: 0x0, Low: 0x40 });
    SPPermission.deleteVersions = new SPPermission({ High: 0x0, Low: 0x80 });
    SPPermission.cancelCheckout = new SPPermission({ High: 0x0, Low: 0x100 });
    SPPermission.managePersonalViews = new SPPermission({ High: 0x0, Low: 0x200 });
    SPPermission.manageLists = new SPPermission({ High: 0x0, Low: 0x800 });
    SPPermission.viewFormPages = new SPPermission({ High: 0x0, Low: 0x1000 });
    SPPermission.open = new SPPermission({ High: 0x0, Low: 0x20000 });
    SPPermission.viewPages = new SPPermission({ High: 0x0, Low: 0x20000 });
    SPPermission.layoutsPage = new SPPermission({ High: 0x0, Low: 0x21000 });
    SPPermission.addAndCustomizePages = new SPPermission({ High: 0x0, Low: 0x40000 });
    SPPermission.applyThemeAndBorder = new SPPermission({ High: 0x0, Low: 0x80000 });
    SPPermission.applyStyleSheets = new SPPermission({ High: 0x0, Low: 0x100000 });
    SPPermission.viewUsageData = new SPPermission({ High: 0x0, Low: 0x200000 });
    SPPermission.createSSCSite = new SPPermission({ High: 0x0, Low: 0x400000 });
    SPPermission.manageSubwebs = new SPPermission({ High: 0x0, Low: 0x800000 });
    SPPermission.createGroups = new SPPermission({ High: 0x0, Low: 0x1000000 });
    SPPermission.managePermissions = new SPPermission({ High: 0x0, Low: 0x2000000 });
    SPPermission.browseDirectories = new SPPermission({ High: 0x0, Low: 0x4000000 });
    SPPermission.browserUserInfo = new SPPermission({ High: 0x0, Low: 0x8000000 });
    SPPermission.addDelPrivateWebParts = new SPPermission({ High: 0x0, Low: 0x10000000 });
    SPPermission.updatePersonalWebParts = new SPPermission({ High: 0x0, Low: 0x20000000 });
    SPPermission.manageWeb = new SPPermission({ High: 0x0, Low: 0x40000000 });
    SPPermission.useClientIntegration = new SPPermission({ High: 0x10, Low: 0x0 });
    SPPermission.useRemoteAPIs = new SPPermission({ High: 0x20, Low: 0x0 });
    SPPermission.manageAlerts = new SPPermission({ High: 0x40, Low: 0x0 });
    SPPermission.createAlerts = new SPPermission({ High: 0x80, Low: 0x0 });
    SPPermission.editMyUserInfo = new SPPermission({ High: 0x100, Low: 0x0 });
    SPPermission.enumeratePermissions = new SPPermission({ High: 0x40000000, Low: 0x0 });
    SPPermission.fullMask = new SPPermission({ High: 0x7FFFFFFF, Low: 0xFFFFFFFF });
    return SPPermission;
}());
exports.default = SPPermission;
