import IClientSideWebPartStatusRenderer from './IClientSideWebPartStatusRenderer';
/**
 * This class provides the default implementation for displaying loading indicator and error messages
 * for web parts. The web part host can decide to provide custom implemenation of how web parts display
 * loading indicators and error messages.
 *
 * @public
 */
export default class ClientSideWebPartStatusRenderer implements IClientSideWebPartStatusRenderer {
    private _errorId;
    private _errorHtml;
    private _logSource;
    private _activeIndicatorCache;
    /**
     * Display a loading spinner.
     *
     * @param domElement - the web part container div.
     * @param loadingMessage - the message to be displayed when the loading spinner id displayed.
     * @param timeout (optional) - timeout to render the loading indicator. Default is 1500ms.
     */
    displayLoadingIndicator(domElement: HTMLElement, loadingMessage: string, timeout?: number): void;
    /**
     * Clear the loading indicator.
     *
     * @param domElement - the web part container div.
     */
    clearLoadingIndicator(domElement: HTMLElement): void;
    /**
     * Render the provided error message in the web part container div.
     * @param domElement - the web part container div.
     * @param error - the error message.
     */
    renderError(domElement: HTMLElement, error: Error | string): void;
    /**
     * Clear the web part error message.
     * @param domElement - the web part container div.
     */
    clearError(domElement: HTMLElement): void;
    private _renderSpinner(domElement, loadingMessage, showSpinner);
    private _getCacheEntry(domElement);
}
