/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file web part manager context.
 */
import { DisplayMode } from '@microsoft/sp-core-library';
import { IClientSideWebPartManifest } from '@microsoft/sp-module-interfaces';
import IWebPartHost from './IWebPartHost';
import IWebPartData from './IWebPartData';
/**
 * Context object that needs to be passed to the web part manager to load a web part.
 *
 * @internal
 */
interface IWebPartManagerContext {
    /**
     * Reference to the DOM element that contains the web part.
     */
    domElement: HTMLElement;
    /**
     * Optional reference to the scrollable element that is common parent of all the web parts.
     */
    scrollableParent?: HTMLElement;
    /**
     * Web part instance id
     */
    instanceId: string;
    /**
     * Web part manifest
     */
    manifest: IClientSideWebPartManifest<any>;
    /**
     * The display mode as one of DisplayMode.Read or DisplayMode.Edit
     */
    displayMode: DisplayMode;
    /**
     * Web psart instance data. This data should be used to render a web part.
     */
    webPartData?: IWebPartData;
    /**
     * Host containing the web part. This host can be any container that implements the IWebPartHost interface. Some
     * examples of hosts are the Canvas, a single page application that contains a web part, and classic SharePoint
     * pages.
     */
    host?: IWebPartHost;
    /**
     * Flag indicating whether the web part is rendered from the persisted data or not. If the web part is added
     * from toolbox, the value of this flag will be false.
     */
    addedFromPersistedData?: boolean;
    /**
     * Callback API when all web parts in the viewport are rendered
     * Usage: When web part not in viewport, loading is delayed.
     */
    onViewportWebPartsRendered?: (endTime: number) => void;
    /**
     * Total number of web parts in store that will be asked to Web Part manager instance for loading
     */
    totalWebparts?: number;
}
export default IWebPartManagerContext;
