import { IClientSideWebPartManifestInstance } from '@microsoft/sp-module-interfaces';
import { HttpClient, SPHttpClient, GraphHttpClient } from '@microsoft/sp-http';
import { BaseComponentContext } from '@microsoft/sp-component-base';
import IClientSideWebPartStatusRenderer from './/IClientSideWebPartStatusRenderer';
import { IEventAggregator } from './events/IEvent';
import IWebPartHost from './IWebPartHost';
import { IPropertyPaneAccessor } from './context/IPropertyPaneAccessor';
import IWebPartContextParameters from './IWebPartContextParameters';
/**
 * Web part context object. This object contains the contextual services available to a web part. e.g.
 * a contextual instance to the http client.
 *
 * @public
 */
export default class WebPartContext extends BaseComponentContext {
    /**
     * {@inheritdoc @microsoft/sp-component-base:BaseComponentContext.manifest}
     */
    readonly manifest: IClientSideWebPartManifestInstance<any>;
    private _webPartTag;
    private _domElement;
    private _httpClient;
    private _spHttpClient;
    private _graphHttpClient;
    private _statusRenderer;
    private _eventAggregator;
    private _setPropertyPaneState;
    private _isPropertyPaneRenderedByWebPart;
    private _isPropertyPaneOpen;
    private _host;
    private _propertyPaneAccessor;
    private _logSource;
    /** @internal */
    constructor(parameters: IWebPartContextParameters);
    /**
     * Web part tag to be used for logging and telemetry.
     */
    readonly webPartTag: string;
    /**
     * Reference to the DOM element that hosts this client side component.
     */
    readonly domElement: HTMLElement;
    /**
     * HttpClient instance scoped to this web part.
     */
    readonly httpClient: HttpClient;
    /**
     * SPHttpClient instance scoped to this web part.
     */
    readonly spHttpClient: SPHttpClient;
    /**
     * GraphHttpClient instance scoped to this web part.
     *
     * @beta
     */
    readonly graphHttpClient: GraphHttpClient;
    /**
     * Web part status renderer.
     */
    readonly statusRenderer: IClientSideWebPartStatusRenderer;
    /**
     * Web part event aggregator.
     *
     * @alpha
     */
    readonly eventAggregator: IEventAggregator;
    /**
     * Accessor for common web part property pane operations.
     */
    readonly propertyPane: IPropertyPaneAccessor;
    /**
     * Web part host.
     *
     * @alpha
     */
    readonly host: IWebPartHost;
}
