/// <reference types="react" />
/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file Base webpart for all React webparts
 */
import * as React from 'react';
import { DisplayMode } from '@microsoft/sp-core-library';
import { IWebPartProps } from '../IWebPartProps';
import BaseClientSideWebPart from '../BaseClientSideWebPart';
/**
 * React web part props
 *
 * @internal
 */
export interface IReactWebPartProps extends IWebPartProps {
    /**
     * The display mode for the summary links component. It is either Read or Edit.
     * This value is read from web part and passed to here.
     */
    mode: DisplayMode;
}
/**
 * Implement some common functionality for a base React webpart. All React based
 * webparts are expected to inherit from this class.
 *
 * @internal
 */
declare abstract class ReactWebPart<TProperties> extends BaseClientSideWebPart<TProperties> {
    private _componentType;
    private _componentInstance;
    constructor(componentType: React.ComponentClass<IReactWebPartProps>);
    render(): void;
    protected onDispose(): void;
}
export default ReactWebPart;
