/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file interfaces to access web part property pane APIs.
 */
/**
 * Web part context property pane accessor interface. Provides some most commonly used operations
 * to access the property pane.
 *
 * @public
 */
export interface IPropertyPaneAccessor {
    /**
     * This API should be used to open the PropertyPane to help configure the web part.
     */
    open(): void;
    /**
     * This API should be used to invoke the PropertyPane to help configure the web part.
     *
     * @remarks
     * This operation only works when the PropertyPane is already open for the currently active web part.
     * If the PropertyPane is opened for another web part, calling the refresh API will have no impact.
     */
    refresh(): void;
    /**
     * Indicates whether the PropertyPane was initially opened by the web part.
     * @remarks
     * For example, if the web part calls this.context.propertyPane.open() then the property would be true,
     * whereas if the property pane was opened by the host, then the value will be false.
     */
    isRenderedByWebPart(): boolean;
    /**
     * Returns true if the PropertyPane is open.
     */
    isPropertyPaneOpen(): boolean;
}
