/**
 * Event object
 *
 * @internal
 */
export interface IEvent<T> {
    sourceId: string;
    targetId: string;
    data?: T;
}
/**
 * Event callback
 *
 * @internal
 */
export interface IEventCallback<T> {
    (eventName: string, eventObject: IEvent<T>): void;
}
/**
 * Publis APIs for the EventAggregator. Event names must follow the following format
 * "eventName:action" e.g. "configure:start" and "configure:end"
 *
 * @internal
 */
export interface IEventAggregator {
    /**
     * Subscribe for an event from all sources
     *
     * @param eventName- Name of the event.
     * @param subscriberId - Id of the subscriber to the event.
     * @param callback - Callback for when the event is raised.
     */
    subscribeByEventName<T>(eventName: string, subscriberId: string, callback: IEventCallback<T>): void;
    /**
     * Subscribe for all events from a specific source.
     *
     * @param sourceId - Source of the event.
     * @param subscriberId - Id of the subscriber to the event.
     * @param callback - Callback for when the event is raised.
     */
    subscribeBySourceId<T>(sourceId: string, subscriberId: string, callback: IEventCallback<T>): void;
    /**
     * Raise an event
     *
     * @param eventName - Event name.
     * @param eventObject - Event object.
     */
    raiseEvent<T>(eventName: string, eventObject: IEvent<T>): void;
}
