"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var decorators_1 = require("@microsoft/decorators");
var React = require("react");
var sp_core_library_1 = require("@microsoft/sp-core-library");
var office_ui_fabric_react_1 = require("office-ui-fabric-react");
var office_ui_fabric_react_2 = require("office-ui-fabric-react");
var MaintenanceModeText_1 = require("./MaintenanceModeText");
var MaintenanceMode_module_scss_1 = require("./MaintenanceMode.module.scss");
var Strings_resx_1 = require("./loc/Strings.resx");
var MaintenanceMode = (function (_super) {
    tslib_1.__extends(MaintenanceMode, _super);
    function MaintenanceMode() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    MaintenanceMode.prototype.render = function () {
        var context = this.props.context;
        var isInternal = !!context.manifest.isInternal;
        var isInternalString = isInternal.toString() + " (" + (isInternal ? Strings_resx_1.default.MadeByMicrosoft : Strings_resx_1.default.NotMadeByMicrosoft) + ")";
        var envStringSuffix = '';
        switch (sp_core_library_1.Environment.type) {
            case 0:
                envStringSuffix = Strings_resx_1.default.Test;
                break;
            case 1:
                envStringSuffix = Strings_resx_1.default.LocalWorkbench;
                break;
            case 2:
                envStringSuffix = Strings_resx_1.default.SharePoint;
                break;
            case 3:
                envStringSuffix = Strings_resx_1.default.ClassicSharePoint;
                break;
        }
        var envString = sp_core_library_1.Environment.type.toString() + " (" + envStringSuffix + ")";
        return (React.createElement("div", { className: MaintenanceMode_module_scss_1.default.maintenanceModeCard },
            React.createElement("div", { className: MaintenanceMode_module_scss_1.default.cardContainer },
                React.createElement("div", { className: MaintenanceMode_module_scss_1.default.cardHeader },
                    React.createElement("span", null, context.manifest.alias),
                    React.createElement(office_ui_fabric_react_1.IconButton, { iconProps: { iconName: 'Copy' }, title: Strings_resx_1.default.CopyToClipboard, ariaLabel: Strings_resx_1.default.CopyToClipboard, className: MaintenanceMode_module_scss_1.default.copyButton, onClick: this._copyData.bind(this) })),
                React.createElement("div", { className: MaintenanceMode_module_scss_1.default.cardBody },
                    React.createElement(office_ui_fabric_react_2.Pivot, null,
                        React.createElement(office_ui_fabric_react_2.PivotItem, { linkText: Strings_resx_1.default.General },
                            React.createElement("div", { className: MaintenanceMode_module_scss_1.default.pivotItem },
                                React.createElement("pre", null,
                                    React.createElement("code", null,
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.Alias, value: context.manifest.alias }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.Id, value: context.manifest.id }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.InstanceId, value: context.instanceId }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.IsInternal, value: isInternalString }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.Version, value: context.manifest.version }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.Environment, value: envString }),
                                        React.createElement(MaintenanceModeText_1.MaintenanceModeText, { label: Strings_resx_1.default.UserAgent, value: navigator.userAgent }))))),
                        React.createElement(office_ui_fabric_react_2.PivotItem, { linkText: Strings_resx_1.default.Manifest, className: MaintenanceMode_module_scss_1.default.pivotItem },
                            React.createElement("div", { className: MaintenanceMode_module_scss_1.default.pivotItemContent },
                                React.createElement("pre", null,
                                    React.createElement("code", null,
                                        React.createElement("span", null, JSON.stringify(context.manifest, undefined, 2)))))),
                        React.createElement(office_ui_fabric_react_2.PivotItem, { linkText: Strings_resx_1.default.Data, className: MaintenanceMode_module_scss_1.default.pivotItem },
                            React.createElement("div", { className: MaintenanceMode_module_scss_1.default.pivotItemContent },
                                React.createElement("pre", null,
                                    React.createElement("code", null,
                                        React.createElement("span", null, JSON.stringify(this.props.data, undefined, 2)))))))))));
    };
    MaintenanceMode.prototype._copyData = function () {
        var details = {}; 
        var context = this.props.context;
        var general = {}; 
        general.alias = context.manifest.alias;
        general.id = context.manifest.id;
        general.instanceId = context.instanceId;
        general.isInternal = context.manifest.isInternal;
        general.version = context.manifest.version;
        general.environment = sp_core_library_1.Environment.type.toString();
        general.userAgent = navigator.userAgent;
        details.general = general;
        details.manifest = context.manifest;
        details.webPartData = this.props.data;
        this._copyDataToClipBoard(JSON.stringify(details, undefined, 2));
    };
    MaintenanceMode.prototype._copyDataToClipBoard = function (data) {
        var result = false;
        if (window.clipboardData && window.window.clipboardData.setData) {
            result = window.clipboardData.setData('Text', data); 
        }
        else if (document.queryCommandSupported && document.queryCommandSupported('copy')) {
            var textarea = document.createElement('textarea');
            textarea.textContent = data;
            textarea.style.position = 'fixed'; 
            textarea.style.height = '0';
            document.body.appendChild(textarea);
            textarea.select();
            try {
                result = document.execCommand('copy'); 
            }
            catch (ex) {
                result = false;
            }
            finally {
                document.body.removeChild(textarea);
            }
        }
        return result;
    };
    MaintenanceMode = tslib_1.__decorate([
        decorators_1.sealed
    ], MaintenanceMode);
    return MaintenanceMode;
}(React.Component));
exports.default = MaintenanceMode;
