/**
 * @Copyright (c) Microsoft Corporation.  All rights reserved.
 *
 * @file Abstract implementation of IPropertyPaneControl.
 */
import { default as IWebPartData } from '../../core/IWebPartData';
import { IPropertyPaneControl } from './IPropertyPaneControl';
import { IPropertyPaneData } from '../propertyPane/IPropertyPane';
import { WebPartConfigurationEvent } from '../propertyPane/PropertyPaneDefinitions';
/**
 * Base implementation of IPropertyPaneControl. Derived classes will be able to use the
 * ClientSideWebPartManager.setPropertyPaneControl API to enable configuration with the
 * application's Property Pane.
 *
 * @internalremarks - We will not be exposing this pattern to third-party developers.
 * @internal
 */
declare abstract class BasePropertyPaneControl implements IPropertyPaneControl {
    abstract _internalDispose(): void;
    abstract _internalGetPropertyPaneData(): IPropertyPaneData;
    abstract _internalOnPropertyPaneFieldChanged(newPropertyPath: string, newValue: any): void;
    _internalOnAfterResize(): void;
    _internalOnConfigurationEvent(configurationEvent: WebPartConfigurationEvent): void;
    _internalSerialize(): IWebPartData | undefined;
}
export default BasePropertyPaneControl;
