/// <reference types="react" />
/**
 * PropertyPane ChoiceGroup icon props.
 *
 * @public
 */
export interface IPropertyPaneChoiceGroupOptionIconProps {
    /**
     * The name of the icon to use from the Office Fabric icon set.
     */
    officeFabricIconFontName?: string | null;
}
/**
 * PropertyPane ChoiceGroup props.
 *
 * @public
 */
export interface IPropertyPaneChoiceGroupProps {
    /**
     * The options for the choice group.
     */
    options: IPropertyPaneChoiceGroupOption[];
    /**
     * Descriptive label for the choice group.
     */
    label?: string;
}
/**
 * PropertyPane ChoiceGroup option props.
 *
 * @public
 */
export interface IPropertyPaneChoiceGroupOption {
    /**
     * A required key to uniquely identify the option.
     */
    key: string | number;
    /**
     * The text string for the option.
     */
    text: string;
    /**
     * The Icon component props for choice field.
     */
    iconProps?: IPropertyPaneChoiceGroupOptionIconProps;
    /**
     * The src of image for choice field.
     */
    imageSrc?: string;
    /**
     * The src of image for choice field which is selected.
     */
    selectedImageSrc?: string;
    /**
     * The width and height of the image in px for choice field.
     */
    imageSize?: {
        width: number;
        height: number;
    };
    /**
     * Whether the property pane choice group option is disabled or not.
     */
    disabled?: boolean;
    /**
     * Whether the property pane choice group option is checked or not.
     *
     * Default value is false.
     */
    checked?: boolean;
}
/**
 * PropertyPane ChoiceGroup option props.
 *
 * @internal
 */
export interface _IPropertyPaneChoiceGroupOptionInternal extends IPropertyPaneChoiceGroupOption {
    /**
     * Optional attribute used for when an SVG is used in a ChoiceGroup component
     * This is necessary to allow the SVG to be themed. This is an element using SVG tags such as:
     *
     * <svg width="400" height="110">
     *   <rect width="300" height="100"/>
     * </svg>
     */
    themableSvg?: JSX.Element;
}
