/**
 * PropertyPane drop down component props.
 *
 * @public
 */
export interface IPropertyPaneDropdownProps {
    /**
     * Descriptive label for the Dropdown.
     */
    label: string;
    /**
     * The key of the initially selected option.
     */
    selectedKey?: string | number;
    /**
     * Collection of options for this Dropdown.
     */
    options?: IPropertyPaneDropdownOption[];
    /**
     * Whether the property pane dropdown option is disabled or not.
     */
    disabled?: boolean;
    /**
     * A description of the dropdown for the benefit of screen reader users.
     */
    ariaLabel?: string;
}
/**
 * PropertyPane drop down options.
 *
 * @public
 */
export interface IPropertyPaneDropdownOption {
    /**
     * A key to uniquely identify this option.
     */
    key: string | number;
    /**
     * Text to render for this option.
     */
    text: string;
    /**
     * Index for this option.
     */
    index?: number;
    /**
     * The type of option. If omitted, the default is PropertyPaneDropdownMenuItemType.Normal
     */
    type?: PropertyPaneDropdownOptionType;
}
/**
 * Specifies the type of option in a dropdown menu rendered by {@link PropertyPaneDropdown}.
 *
 * @public
 */
export declare enum PropertyPaneDropdownOptionType {
    /**
     * Render normal menu item.
     */
    Normal = 0,
    /**
     * Render a divider.
     */
    Divider = 1,
    /**
     * Render menu item as a header.
     */
    Header = 2,
}
