/**
 * PropertyPane field.
 *
 * @public
 */
export interface IPropertyPaneField<TProperties> {
    /**
     * Type of the PropertyPane field.
     */
    type: PropertyPaneFieldType;
    /**
     * Target property from the web part's property bag.
     */
    targetProperty: string;
    /**
     * Whether this control should be focused.
     *
     * @remarks
     * The default value is false.
     */
    shouldFocus?: boolean;
    /**
     * Strongly typed properties object. Specific to each field type.
     *
     * @remarks
     * Example: Checkbox has ICheckboxProps, TextField has ITextField props.
     *
      * @internalremarks - These props are from the office-ui-fabric-react.
      *   These props may not be extensive as the fabric-react ones. This is intentional.
      *     - We are not including any callbacks as part of the props, as this might end up breaking
      *       the internal flow and cause unwanted problems.
      *     - Currently discussions are going on whether to include styling elements or not. Based on
      *       the output of the discussions, changes to the styling related props will take place.
      *
      *   We are including only those which are supported by the web part framework.
     */
    properties: TProperties;
}
/**
 * Enum for all the supported PropertyPane field types.
 *
 * Names should be consistent with those in office-ui-fabric-react, be careful to get letter casing correct.
 *
 * @public
 */
export declare enum PropertyPaneFieldType {
    /**
     * Custom field.
     */
    Custom = 1,
    /**
     * Checkbox field.
     */
    CheckBox = 2,
    /**
     * TextField field.
     */
    TextField = 3,
    /**
     * Toggle field.
     */
    Toggle = 5,
    /**
     * Dropdown field.
     */
    Dropdown = 6,
    /**
     * Label field.
     */
    Label = 7,
    /**
     * Slider field.
     */
    Slider = 8,
    /**
     * Heading field.
     */
    Heading = 9,
    /**
     * Choice Group field.
     */
    ChoiceGroup = 10,
    /**
     * Button field.
     */
    Button = 11,
    /**
     * Horizontal Rule field.
     */
    HorizontalRule = 12,
    /**
     * Link field.
     */
    Link = 13,
}
