/**
 * PropertyPaneLink component props.
 *
 * @public
 */
export interface IPropertyPaneLinkProps {
    /**
     * Display text for the link.
     */
    text: string;
    /**
     * Location to which the link is targeted to.
     */
    href: string;
    /**
     * This attribute specifies where to display the linked resource.
     *
     * @remarks
     * Following values can be used:
     *
     * _self - (default) Load the response in the current page.
     *
     * _blank - Load the response into a new unnamed tab.
     *
     * _parent - Load the response in the parent of the current page.
     *           If no parent exists, then this option behaves same as "_self"
     *
     * _top - Load the response into the original window.
     */
    target?: string;
    /**
     *  The props of pop up window.
     */
    popupWindowProps?: IPopupWindowProps;
    /**
     * Whether the property pane link is disabled or not.
     */
    disabled?: boolean;
}
/**
 * Popup window props.
 *
 * @public
 */
export interface IPopupWindowProps {
    /**
     * Title of pop up window.
     */
    title: string;
    /**
     * Width of pop up window.
     */
    width: number;
    /**
     * Height of pop up window.
     */
    height: number;
    /**
     * The position of pop up window.
     */
    positionWindowPosition: PopupWindowPosition;
}
/**
 * The position of pop up window.
 *
 * @public
 */
export declare enum PopupWindowPosition {
    /**
     * PopupWindowPosition would be located in center of screen.
     */
    center = 0,
    /**
     * PopupWindowPosition would be located in right top of screen.
     */
    rightTop = 1,
    /**
     * PopupWindowPosition would be located in left top of screen.
     */
    leftTop = 2,
    /**
     * PopupWindowPosition would be located in right bottom of screen.
     */
    rightBottom = 3,
    /**
     * PopupWindowPosition would be located in left bottom of screen.
     */
    leftBottom = 4,
}
