define(["require", "exports", "./Stylesheet", "./transforms/kebabRules", "./transforms/prefixRules", "./transforms/provideUnits", "./transforms/rtlifyRules"], function (require, exports, Stylesheet_1, kebabRules_1, prefixRules_1, provideUnits_1, rtlifyRules_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var DISPLAY_NAME = 'displayName';
    function getDisplayName(rules) {
        var rootStyle = rules && rules['&'];
        return rootStyle ? rootStyle.displayName : undefined;
    }
    function extractRules(args, rules, currentSelector) {
        if (rules === void 0) { rules = { __order: [] }; }
        if (currentSelector === void 0) { currentSelector = '&'; }
        var stylesheet = Stylesheet_1.Stylesheet.getInstance();
        var currentRules = rules[currentSelector];
        if (!currentRules) {
            currentRules = {};
            rules[currentSelector] = currentRules;
            rules.__order.push(currentSelector);
        }
        for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
            var arg = args_1[_i];
            // If the arg is a string, we need to look up the class map and merge.
            if (typeof arg === 'string') {
                var expandedRules = stylesheet.argsFromClassName(arg);
                if (expandedRules) {
                    extractRules(expandedRules, rules, currentSelector);
                }
                // Else if the arg is an array, we need to recurse in.
            }
            else if (Array.isArray(arg)) {
                extractRules(arg, rules, currentSelector);
            }
            else {
                // tslint:disable-next-line:no-any
                for (var prop in arg) {
                    if (prop === 'selectors') {
                        // tslint:disable-next-line:no-any
                        var selectors = arg.selectors;
                        for (var newSelector in selectors) {
                            if (selectors.hasOwnProperty(newSelector)) {
                                var selectorValue = selectors[newSelector];
                                if (newSelector.indexOf(':global(') === 0) {
                                    newSelector = newSelector.replace(/:global\(|\)$/g, '');
                                }
                                else if (newSelector.indexOf('@media') === 0) {
                                    newSelector = newSelector + '{' + currentSelector;
                                }
                                else if (newSelector.indexOf(':') === 0) {
                                    newSelector = currentSelector + newSelector;
                                }
                                else if (newSelector.indexOf('&') < 0) {
                                    newSelector = currentSelector + ' ' + newSelector;
                                }
                                extractRules([selectorValue], rules, newSelector);
                            }
                        }
                    }
                    else {
                        // Else, add the rule to the currentSelector.
                        if (prop === 'margin' || prop === 'padding') {
                            // tslint:disable-next-line:no-any
                            expandQuads(currentRules, prop, arg[prop]);
                        }
                        else {
                            // tslint:disable-next-line:no-any
                            currentRules[prop] = arg[prop];
                        }
                    }
                }
            }
        }
        return rules;
    }
    function expandQuads(currentRules, name, value) {
        var parts = (typeof value === 'string') ? value.split(' ') : [value];
        currentRules[name + 'Top'] = parts[0];
        currentRules[name + 'Right'] = parts[1] || parts[0];
        currentRules[name + 'Bottom'] = parts[2] || parts[0];
        currentRules[name + 'Left'] = parts[3] || parts[1] || parts[0];
    }
    function getKeyForRules(rules) {
        var serialized = [];
        var hasProps = false;
        for (var _i = 0, _a = rules.__order; _i < _a.length; _i++) {
            var selector = _a[_i];
            serialized.push(selector);
            var rulesForSelector = rules[selector];
            for (var propName in rulesForSelector) {
                if (rulesForSelector.hasOwnProperty(propName) && rulesForSelector[propName] !== undefined) {
                    hasProps = true;
                    serialized.push(propName, rulesForSelector[propName]);
                }
            }
        }
        return hasProps ? serialized.join('') : undefined;
    }
    function serializeRuleEntries(ruleEntries) {
        if (!ruleEntries) {
            return '';
        }
        var allEntries = [];
        for (var entry in ruleEntries) {
            if (ruleEntries.hasOwnProperty(entry) && entry !== DISPLAY_NAME && ruleEntries[entry] !== undefined) {
                allEntries.push(entry, ruleEntries[entry]);
            }
        }
        // Apply transforms.
        for (var i = 0; i < allEntries.length; i += 2) {
            kebabRules_1.kebabRules(allEntries, i);
            provideUnits_1.provideUnits(allEntries, i);
            rtlifyRules_1.rtlifyRules(allEntries, i);
            prefixRules_1.prefixRules(allEntries, i);
        }
        // Apply punctuation.
        for (var i = 1; i < allEntries.length; i += 4) {
            allEntries.splice(i, 1, ':', allEntries[i], ';');
        }
        return allEntries.join('');
    }
    exports.serializeRuleEntries = serializeRuleEntries;
    function styleToRegistration() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var rules = extractRules(args);
        var key = getKeyForRules(rules);
        if (key) {
            var stylesheet = Stylesheet_1.Stylesheet.getInstance();
            var registration = {
                className: stylesheet.classNameFromKey(key),
                key: key,
                args: args
            };
            if (!registration.className) {
                registration.className = stylesheet.getClassName(getDisplayName(rules));
                var rulesToInsert = [];
                for (var _a = 0, _b = rules.__order; _a < _b.length; _a++) {
                    var selector = _b[_a];
                    rulesToInsert.push(selector, serializeRuleEntries(rules[selector]));
                }
                registration.rulesToInsert = rulesToInsert;
            }
            return registration;
        }
    }
    exports.styleToRegistration = styleToRegistration;
    function applyRegistration(registration, classMap) {
        var stylesheet = Stylesheet_1.Stylesheet.getInstance();
        var className = registration.className, key = registration.key, args = registration.args, rulesToInsert = registration.rulesToInsert;
        if (rulesToInsert) {
            // rulesToInsert is an ordered array of selector/rule pairs.
            for (var i = 0; i < rulesToInsert.length; i += 2) {
                var rules = rulesToInsert[i + 1];
                if (rules) {
                    var selector = rulesToInsert[i];
                    // Fix selector using map.
                    selector = selector.replace(/(&)|\$([\w-]+)\b/g, function (match, amp, cn) {
                        if (amp) {
                            return '.' + registration.className;
                        }
                        else if (cn) {
                            return '.' + ((classMap && classMap[cn]) || cn);
                        }
                        return '';
                    });
                    // Insert. Note if a media query, we must close the query with a final bracket.
                    var processedRule = selector + "{" + rules + "}" + ((selector.indexOf('@media') === 0) ? '}' : '');
                    stylesheet.insertRule(processedRule);
                }
            }
            stylesheet.cacheClassName(className, key, args, rulesToInsert);
        }
    }
    exports.applyRegistration = applyRegistration;
    function styleToClassName() {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        var registration = styleToRegistration.apply(void 0, args);
        if (registration) {
            applyRegistration(registration);
            return registration.className;
        }
        return '';
    }
    exports.styleToClassName = styleToClassName;
});
//# sourceMappingURL=styleToClassName.js.map