define(["require", "exports", "./CommonStyles", "@uifabric/utilities/lib/initializeFocusRects", "./zIndexes"], function (require, exports, CommonStyles_1, initializeFocusRects_1, zIndexes_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    /**
     * Generates a focus style which can be used to define an :after focus border.
     *
     * @param theme - The theme object to use.
     * @param inset - The number of pixels to inset the border.
     * @param color - The color for the border.
     * @param position - The positioning applied to the container. Must
     * be 'relative' or 'absolute' so that the focus border can live around it.
     * @param highContrastStyle - Style for high contrast mode.
     * @returns The style object.
     */
    function getFocusStyle(theme, inset, position, highContrastStyle) {
        if (inset === void 0) { inset = 0; }
        if (position === void 0) { position = 'relative'; }
        if (highContrastStyle === void 0) { highContrastStyle = undefined; }
        return {
            outline: 'transparent',
            position: position,
            selectors: (_a = {
                    '::-moz-focus-inner': {
                        border: '0'
                    }
                },
                _a["." + initializeFocusRects_1.IsFocusVisibleClassName + " &:focus:after"] = {
                    content: '""',
                    position: 'absolute',
                    left: inset + 1,
                    top: inset + 1,
                    bottom: inset + 1,
                    right: inset + 1,
                    border: '1px solid ' + theme.palette.white,
                    outline: '1px solid ' + theme.palette.neutralSecondary,
                    zIndex: zIndexes_1.ZIndexes.FocusStyle,
                    selectors: (_b = {},
                        _b[CommonStyles_1.HighContrastSelector] = highContrastStyle,
                        _b)
                },
                _a)
        };
        var _a, _b;
    }
    exports.getFocusStyle = getFocusStyle;
    /**
     * Generates style to clear browser specific focus styles.
     */
    function focusClear() {
        return {
            selectors: {
                '&::-moz-focus-inner': {
                    // Clear the focus border in Firefox. Reference: http://stackoverflow.com/a/199319/1436671
                    border: 0
                },
                '&': {
                    // Clear browser specific focus styles and use transparent as placeholder for focus style
                    outline: 'transparent'
                }
            }
        };
    }
    exports.focusClear = focusClear;
});
//# sourceMappingURL=getFocusStyle.js.map