define(["require", "exports", "./dom", "./localStorage"], function (require, exports, dom_1, localStorage_1) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    // Default to undefined so that we initialize on first read.
    var _language;
    /**
     * Gets the rtl state of the page (returns true if in rtl.)
     *
     * @public
     */
    function getLanguage() {
        if (_language === undefined) {
            var doc = dom_1.getDocument();
            var savedLanguage = localStorage_1.getItem('language');
            if (savedLanguage !== null) {
                _language = savedLanguage;
            }
            if (_language === undefined && doc) {
                _language = doc.documentElement.getAttribute('lang');
            }
            if (_language === undefined) {
                _language = 'en';
            }
        }
        return _language;
    }
    exports.getLanguage = getLanguage;
    /**
     * Sets the rtl state of the page (by adjusting the dir attribute of the html element.)
     *
     * @public
     */
    function setLanguage(language, avoidPersisting) {
        if (avoidPersisting === void 0) { avoidPersisting = false; }
        var doc = dom_1.getDocument();
        if (doc) {
            doc.documentElement.setAttribute('lang', language);
        }
        if (!avoidPersisting) {
            localStorage_1.setItem('language', language);
        }
        _language = language;
    }
    exports.setLanguage = setLanguage;
});
//# sourceMappingURL=language.js.map