/**
 * An array of events that are allowed on every html element type.
 *
 * @public
 */
export declare const baseElementEvents: string[];
/**
 * An array of element attributes which are allowed on every html element type.
 *
 * @public
 */
export declare const baseElementProperties: string[];
/**
 * An array of HTML element properties and events.
 *
 * @public
 */
export declare const htmlElementProperties: string[];
/**
 * An array of A tag properties and events.
 *
 * @public
 */
export declare const anchorProperties: string[];
/**
 * An array of BUTTON tag properties and events.
 *
 * @public
 */
export declare const buttonProperties: string[];
/**
 * An array of DIV tag properties and events.
 *
 * @public
 */
export declare const divProperties: string[];
/**
 * An array of INPUT tag properties and events.
 *
 * @public
 */
export declare const inputProperties: string[];
/**
 * An array of TEXTAREA tag properties and events.
 *
 * @public
 */
export declare const textAreaProperties: string[];
/**
 * An array of IMAGE tag properties and events.
 *
 * @public
 */
export declare const imageProperties: string[];
/**
 * Gets native supported props for an html element provided the allowance set. Use one of the property
 * sets defined (divProperties, buttonPropertes, etc) to filter out supported properties from a given
 * props set. Note that all data- and aria- prefixed attributes will be allowed.
 * NOTE: getNativeProps should always be applied first when adding props to a react component. The
 * non-native props should be applied second. This will prevent getNativeProps from overriding your custom props.
 * For example, if props passed to getNativeProps has an onClick function and getNativeProps is added to
 * the component after an onClick function is added, then the getNativeProps onClick will override it.
 *
 * @public
 * @param props - The unfiltered input props
 * @param allowedPropsNames-  The array of allowed propnames.
 * @returns The filtered props
 */
export declare function getNativeProps<T>(props: {}, allowedPropNames: string[], excludedPropNames?: string[]): T;
